@@ -2,8 +2,8 @@
 
 ;; Copyright (C) 2020 Kinney Zhang
 ;;
-;; Package-Version: 2.4.3
-;; Package-Revision: 2552444f1037
+;; Package-Version: 20251114.648
+;; Package-Revision: b2b580731ce5
 ;; Keywords: org, convenience
 ;; Author: Kinney Zhang <kinneyzhang666@gmail.com>
 ;; URL: https://github.com/Kinneyzhang/gkroam
@@ -120,6 +120,7 @@
 (require 'org-element)
 (require 'db)
 (require 'company)
+(require 'calendar)
 (eval-when-compile
   (require 'subr-x)
   (require 'hl-line)
@@ -151,8 +152,9 @@
   :group 'gkroam)
 
 (defcustom gkroam-window-margin 2
-  "Gkroam window's left and right margin."
-  :type 'integer
+  "Gkroam window's left and right margin, or nil to ignore margin settings."
+  :type '(choice (integer :tag "Number of spaces")
+                 (const :tag "Ignore margin settings" nil))
   :group 'gkroam)
 
 (defcustom gkroam-use-default-filename nil
@@ -161,7 +163,7 @@ The default format is '%Y%m%d%H%M%S' time string."
   :type 'boolean
   :group 'gkroam)
 
-(defcustom gkroam-show-brackets-p nil
+(defcustom gkroam-show-brackets-flag nil
   "Non-nil means to show brackets in page link."
   :type 'boolean
   :group 'gkroam)
@@ -205,6 +207,12 @@ The default format is '%Y%m%d%H%M%S' time string."
   "^ *\\([0-9]+[).]\\|[*+-]\\) \\(\\[[ X-]\\] \\)?"
   "Org list bullet and checkbox regexp.")
 
+(defvar gkroam-checkbox-todo-icon "□"
+  "The todo checkbox icon.")
+
+(defvar gkroam-checkbox-done-icon "■"
+  "The done checkbox icon.")
+
 (defvar gkroam-has-link-p nil
   "Judge if has link or hashtag in gkroam buffer.")
 
@@ -239,7 +247,7 @@ The default format is '%Y%m%d%H%M%S' time string."
   "\\[\\[file:\\(.+?\\)::[0-9]+\\]\\[.+?\\]\\]"
   "Regular expression that matches a gkroam backlink.")
 
-(defvar gkroam-prettify-page-p nil
+(defvar gkroam-prettify-page-flag nil
   "Non-nil means to prettify gkroam page.")
 
 (defvar gkroam-return-wconf nil
@@ -666,7 +674,7 @@ Output matched files' path and context."
                (message "%s reference updated" page)))
            (gkroam-list-parent-item-overlay reference-start)
            (gkroam-reference-region-overlay reference-start)
-           (when gkroam-prettify-page-p
+           (when gkroam-prettify-page-flag
              (gkroam-org-list-fontify reference-start (point-max)))
            (unless (get-text-property reference-start 'read-only)
              (put-text-property reference-start (point-max)
@@ -1000,7 +1008,9 @@ to linked references for TITLE page."
         (with-temp-buffer
           (insert-file-contents file nil 0 2000 t)
           (goto-char (point-min))
-          (when (re-search-forward (format "^ *#\\+TITLE: *%s *$" (regexp-quote title)) nil t)
+          (when (re-search-forward
+
+                 (format "^ *#\\+TITLE: *%s *$" (regexp-quote title)) nil t)
             (throw 'break page)))))))
 
 (defun gkroam--all-pages ()
@@ -1072,12 +1082,12 @@ to a \"%Y-%m-%d %H-%M-%S\" time string."
 
 (defun gkroam-cache-curr-page (title)
   "Cache gkroam page's filename, which titled with TITLE."
-  (let* ((db-page (gkroam-db-get gkroam-page-db title "page"))
-         (page (gkroam--get-page title))
-         (word-count (gkroam--get-meta :count page))
-         (mentions (gkroam--get-meta :mention page))
-         (created-time (gkroam--get-meta :create page))
-         (updated-time (gkroam--get-meta :update page)))
+  (when-let* ((db-page (gkroam-db-get gkroam-page-db title "page"))
+              (page (gkroam--get-page title)))
+    (let* ((word-count (gkroam--get-meta :count page))
+           (mentions (gkroam--get-meta :mention page))
+           (created-time (gkroam--get-meta :create page))
+           (updated-time (gkroam--get-meta :update page))))
     (unless (equal db-page page)
       (db-put title `(("page" . ,page)
                       ("count" . ,word-count)
@@ -1086,6 +1096,9 @@ to a \"%Y-%m-%d %H-%M-%S\" time string."
                       ("update" . ,updated-time))
               gkroam-page-db))))
 
+(exec-path)
+(executable-find "rg")
+
 (defun gkroam-db-get (db title key)
   "Get KEY attribute's value of TITLE page from DB database."
   (cdr (assoc key (db-get title db))))
@@ -1106,8 +1119,8 @@ to a \"%Y-%m-%d %H-%M-%S\" time string."
 (defun gkroam-update-page-cache ()
   "Update current gkroam page's cache."
   (when (gkroam-work-p)
-    (let* ((page (file-name-nondirectory (buffer-file-name)))
-           (title (gkroam-retrive-title page)))
+    (when-let* ((page (file-name-nondirectory (buffer-file-name)))
+                (title (gkroam-retrive-title page)))
       (unless (null title)
         (gkroam-db-update gkroam-page-db title "page" page)
         (gkroam-db-update gkroam-page-db title "count" (gkroam-word-count))
@@ -1187,7 +1200,9 @@ Output matched files' path."
 (defun gkroam-daily ()
   "Create or open gkroam daily notes."
   (interactive)
-  (let* ((title (format-time-string "%b %d, %Y")))
+  (let* ((month (calendar-month-name
+                 (string-to-number (format-time-string "%m")) t))
+         (title (concat month (format-time-string " %d, %Y"))))
     (gkroam-find title)))
 
 ;;;###autoload
@@ -1210,9 +1225,8 @@ If WITHOUT-HEADLINE is non-nil, don't format headline in link."
                           "Choose a headline or press \"C-p RET\" (\"RET\") to skip: "
                           headlines-exist-p nil nil)))
              (alias (or alias
-                        (completing-read
-                         "Give an alias or press \"RET\" to skip: "
-                         nil nil nil))))
+                        (read-string
+                         "Give an alias or press \"RET\" to skip: "))))
         (when (string= headline "") (setq headline nil))
         (when (string= alias "") (setq alias nil))
         (when headline
@@ -1352,7 +1366,7 @@ PROPS contains properties and values."
     (mapc (lambda (num)
             (setq columns (+ columns (+ num gkroam-index-key-space-num))))
           max-len-lst)
-    (if gkroam-prettify-page-p
+    (if gkroam-prettify-page-flag
         (+ columns gkroam-window-margin)
       columns)))
 
@@ -1424,7 +1438,7 @@ PROPS contains properties and values."
            overlay-beg overlay-end
            'display (gkroam--valign-space right-pixel)))
         (newline)))
-    (let ((gkroam-show-brackets-p nil))
+    (let ((gkroam-show-brackets-flag nil))
       (gkroam-fontify-link))
     (gkroam-prettify-page)
     (setq truncate-lines t)
@@ -1443,7 +1457,7 @@ Turning on this mode runs the normal hook `gkroam-mentions-mode-hook'."
   (if gkroam-mentions-mode
       (progn
         (jit-lock-register #'gkroam-unlinked-title-fontify)
-        (if gkroam-prettify-page-p
+        (if gkroam-prettify-page-flag
             (let* ((spaces (make-string gkroam-window-margin ?\s))
                    (header-format
                     (concat "\\<gkroam-mentions-mode-map>"
@@ -1515,7 +1529,7 @@ If TYPE equals to 'unlinked', get title of `gkroam-unlinked-buf'."
       (gkroam-prettify-page)
       (gkroam-list-parent-item-overlay (point-min))
       (gkroam-reference-region-overlay (point-min))
-      (when gkroam-prettify-page-p
+      (when gkroam-prettify-page-flag
         (gkroam-org-list-fontify (point-min) (point-max)))
       (goto-char (point-min))
       (gkroam-mentions-mode))))
@@ -1740,7 +1754,7 @@ With optional argument ALIAS, format also with alias."
                        (concat title " » " headline)
                      title)))
         (unless (equal (char-to-string (char-before (match-beginning 0))) "#")
-          (if gkroam-show-brackets-p
+          (if gkroam-show-brackets-flag
               (gkroam--fontify-show-brackets)
             (gkroam--fontify-hide-brackets)))
         (with-silent-modifications
@@ -1770,7 +1784,7 @@ With optional argument ALIAS, format also with alias."
 
 (define-minor-mode gkroam-link-mode
   "Recognize gkroam link."
-  t nil nil
+  :lighter ""
   (when (gkroam-work-p)
     (if gkroam-link-mode
         (progn
@@ -1795,9 +1809,9 @@ With optional argument ALIAS, format also with alias."
      '(display "•"))
     (when (match-beginning 2)
       (pcase (match-string-no-properties 2)
-        ("[-] " (gkroam--fontify-org-checkbox "☐"))
-        ("[ ] " (gkroam--fontify-org-checkbox "☐"))
-        ("[X] " (gkroam--fontify-org-checkbox "☑"))))))
+        ("[-] " (gkroam--fontify-org-checkbox gkroam-checkbox-todo-icon))
+        ("[ ] " (gkroam--fontify-org-checkbox gkroam-checkbox-todo-icon))
+        ("[X] " (gkroam--fontify-org-checkbox gkroam-checkbox-done-icon))))))
 
 (defun gkroam-org-list-fontify (beg end)
   "Highlight org list bullet between BEG and END."
@@ -1860,7 +1874,7 @@ With optional argument ALIAS, format also with alias."
   (save-excursion
     (goto-char beg)
     (when (re-search-forward "\\(^ *#\\+TITLE: *\\)\\(.+\\)$" bound t)
-      (if gkroam-prettify-page-p
+      (if gkroam-prettify-page-flag
           (progn
             (gkroam-overlay-region (match-beginning 1) (match-end 1) 'display "")
             (gkroam-overlay-region (match-beginning 2) (match-end 2)
@@ -1891,11 +1905,11 @@ With optional argument ALIAS, format also with alias."
 
 (defun gkroam-set-window-margin ()
   "Set gkroam pages' window margin."
-  (if gkroam-prettify-page-p
+  (if (and gkroam-prettify-page-flag
+           gkroam-window-margin)
       (set-window-margins (selected-window)
                           gkroam-window-margin
-                          gkroam-window-margin)
-    (set-window-margins (selected-window) 0 0)))
+                          gkroam-window-margin)))
 
 (defun gkroam-preserve-window-margin ()
   "Preserve gkroam pages' window margin."
@@ -1908,7 +1922,7 @@ With optional argument ALIAS, format also with alias."
 (defun gkroam-prettify-page ()
   "Prettify gkroam page."
   (when (gkroam-work-p)
-    (if gkroam-prettify-page-p
+    (if gkroam-prettify-page-flag
         (gkroam-prettify-mode 1)
       (gkroam-prettify-mode -1))
     (gkroam-set-window-margin)))
@@ -1928,11 +1942,11 @@ With optional argument ALIAS, format also with alias."
 (defun gkroam-toggle-brackets ()
   "Determine whether to show brackets in page link."
   (interactive)
-  (if gkroam-show-brackets-p
+  (if gkroam-show-brackets-flag
       (progn
-        (setq gkroam-show-brackets-p nil)
+        (setq gkroam-show-brackets-flag nil)
         (message "Hide gkroam link brackets"))
-    (setq gkroam-show-brackets-p t)
+    (setq gkroam-show-brackets-flag t)
     (message "Show gkroam link brackets"))
   (let ((windows (window-list)))
     (save-selected-window
@@ -1945,11 +1959,11 @@ With optional argument ALIAS, format also with alias."
 (defun gkroam-toggle-prettify ()
   "Toggle gkroam page prettification."
   (interactive)
-  (if gkroam-prettify-page-p
+  (if gkroam-prettify-page-flag
       (progn
-        (setq gkroam-prettify-page-p nil)
+        (setq gkroam-prettify-page-flag nil)
         (message "Page prettification is turned off"))
-    (setq gkroam-prettify-page-p t)
+    (setq gkroam-prettify-page-flag t)
     (message "Page prettification is turned on"))
   (let ((windows (window-list)))
     (save-selected-window
@@ -2081,9 +2095,10 @@ With optional argument ALIAS, format also with alias."
     (when (or (gkroam-at-linked-buf)
               (gkroam-at-unlinked-buf))
       (gkroam-mentions-mode -1))
-    (set-window-margins (selected-window) 0 0)
-    (with-silent-modifications
-      (set-text-properties (point-min) (point-max) nil))))
+    (gkroam-preserve-window-margin)
+    (when (gkroam-work-p)
+      (with-silent-modifications
+        (set-text-properties (point-min) (point-max) nil)))))
 
 (provide 'gkroam)
 ;;; gkroam.el ends here
